@@ -4,8 +4,8 @@
 /* -------------------------- Gammu specific ---------------------------- */
 
 /* Version of package */
-#define GAMMU_VERSION "1.37.91"
-#define GAMMU_VERSION_NUM 13791
+#define GAMMU_VERSION "1.38.1"
+#define GAMMU_VERSION_NUM 13801
 
 /* Define if want DEBUG info */
 /* #undef DEBUG */
@@ -280,6 +280,10 @@
 #ifndef HAVE_STRTOULL
 #define HAVE_STRTOULL
 #endif
+/* Size of wchar_t needs to be 4 bytes to store supplementary plan unicode */
+#if 4 >= 4
+#define USE_WCHAR_T
+#endif
 #ifndef HAVE_WCHAR_T
 #define HAVE_WCHAR_T
 #endif
